## pooling problem
## Leo Liberti (from Greenberg's paper)

## user-configurable
param M := 1e3; # large number
param eps := 1e-3; # small number

## sets
# sources
param Imax, integer, > 0;
set I := 1..Imax;
# pools
param Pmax, integer, > 0;
set P := 1..Pmax;
# products
param Jmax, integer, > 0;
set J := 1..Jmax;
# attributes
param Kmax, integer, > 0;
set K := 1..Kmax;

## inputs (Nm) and outputs (Np) for each pool
set Nm{P} default {};
set Np{P} default {};
	
## parameters
# supply
param S{I} default 0;
# demand
param D{J} default 0;
# attribute k in source i
param A{I,K} default 0;
# quality bounds for attribute k in product j
param L{J,K} default 0;
param U{j in J, k in K} >= L[j,k], default M;
# costs
param cI{I} default 0;
param cJ{J} default 0;

### decision variables
# flow from source to pool
var x{I,P} >= 0, <= M;
# flow from pool to product
var y{P,J} >= 0, <= M;
# attribute k in pool p
var q{P,K} >= 0, <= 1;
# attribute k in product j
var Q{j in J, k in K} >= L[j,k], <= U[j,k];

